RemoteCache

Type Alias RemoteCache 

pub type RemoteCache = HashMap<Url, Result<AnchorTargets>>;
If a URL is not stored in the map (the URL does not appear as a key), it means that URL has not yet been checked.

If the Result is Err, it means the URL has been checked, but was not available, or anchor parsing has failed. If the Option is None, it means the URL was checked and evaluated as for available, but no parsing of anchors was tried. If the Vec is empty, it means that the document was parsed, but no anchors were found.

Aliased Type

pub struct RemoteCache { /* private fields */ }